//===--- TextDiagnostics.cpp - Text Diagnostics Parent Class --------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//
//
// This is the parent class for all text diagnostics.
//
//===----------------------------------------------------------------------===//

#include "DiagnosticBuffer.h"
using namespace clang;

DiagnosticBuffer::DiagnosticBuffer() {
}

DiagnosticBuffer:: ~DiagnosticBuffer() {
}

/// HandleDiagnostic - Store the errors & warnings that are reported.
/// 
void DiagnosticBuffer::HandleDiagnostic(Diagnostic &Diags,
                                        Diagnostic::Level Level,
                                        FullSourceLoc Pos,
                                        diag::kind ID,
                                        const std::string *Strs,
                                        unsigned NumStrs,
                                        const SourceRange *SRange,
                                        unsigned NumRanges) {
  DiagItem DI;
  DI.Pos = Pos;
  DI.DiagID = ID;
  for (unsigned i = 0 ; i < NumStrs ; ++i) {
    DI.Strs.push_back(Strs[i]);
  }
  for (unsigned i = 0 ; i < NumRanges ; ++i) {
    DI.Ranges.push_back(SRange[i]);
  }
  DiagItems.push_back(DI);
}
