//===--- DiagnosticBuffer.h - Diagnostic Buffer for Distribution-*- C++ -*-===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//
//
// This class stores the generated diagnostics.
//
//===----------------------------------------------------------------------===//

#ifndef DIAGNOSTIC_BUFFER_H_
#define DIAGNOSTIC_BUFFER_H_

#include <vector>
#include "clang/Basic/Diagnostic.h"

namespace clang {
/*
  void Report(FullSourceLoc Pos, unsigned DiagID,
              const std::string *Strs = 0, unsigned NumStrs = 0,
              const SourceRange *Ranges = 0, unsigned NumRanges = 0) {
DiagID is a member of the
  /// diag::kind enum.  
*/

class DiagnosticBuffer : public DiagnosticClient {
public:

  struct DiagItem {
    FullSourceLoc Pos;
    unsigned DiagID;
    std::vector<std::string> Strs;
    std::vector<SourceRange> Ranges;
  };

  std::vector<DiagItem> DiagItems;
  
  DiagnosticBuffer();
  virtual ~DiagnosticBuffer();

  virtual void HandleDiagnostic(Diagnostic &Diags, Diagnostic::Level DiagLevel,
                                FullSourceLoc Pos,
                                diag::kind ID,
                                const std::string *Strs,
                                unsigned NumStrs,
                                const SourceRange *Ranges, 
                                unsigned NumRanges);
};

} // end namspace clang

#endif
